@@ -94,3 +94,9 @@ bool DevicesProxyModel::duplicateIndexAddress(const QModelIndex &idx) const
     return list.size() > 1;
 }
 
+bool DevicesProxyModel::filterAcceptsRow(int source_row, const QModelIndex &source_parent) const
+{
+    const QModelIndex index = sourceModel()->index(source_row, 0, source_parent);
+    // Only show paired devices in the KCM and applet
+    return index.data(BluezQt::DevicesModel::PairedRole).toBool();
+}
