@@ -1,19 +1,8 @@
 /*
-    Copyright (C) 2010 Alex Fiestas <alex@eyeos.org>
-    Copyright (C) 2010 UFO Coders <info@ufocoders.com>
+    SPDX-FileCopyrightText: 2010 Alex Fiestas <alex@eyeos.org>
+    SPDX-FileCopyrightText: 2010 UFO Coders <info@ufocoders.com>
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-3.0-or-later
 */
 
 #include "discover.h"
@@ -25,6 +14,7 @@
 #include <QAction>
 #include <QSortFilterProxyModel>
 #include <QRegularExpressionValidator>
+#include <QScroller>
 
 #include <KMessageWidget>
 #include <KLocalizedString>
@@ -159,6 +149,8 @@ void DiscoverPage::initializePage()
     connect(m_manager, &BluezQt::Manager::adapterChanged, this, &DiscoverPage::checkAdapters);
     connect(m_manager, &BluezQt::Manager::bluetoothBlockedChanged, this, &DiscoverPage::checkAdapters);
     connect(m_manager, &BluezQt::Manager::usableAdapterChanged, this, &DiscoverPage::usableAdapterChanged);
+
+    QScroller::grabGesture(deviceView);
 }
 
 bool DiscoverPage::isComplete() const
